@@ -868,8 +868,8 @@ gb_eval_context_eval (GBEvalContext *ec,
 		if (class->eval)
 			val = class->eval (ec, e);
 		else
-			val = gb_eval_exception_firev (ec, "Cannot evaluate "
-						       "non constant expression");
+			val = gb_eval_exception_firev (ec, _("Cannot evaluate "
+						       "non constant expression"));
 	}
 
 	return val;	
