@@ -115,7 +115,7 @@ read_dot (GBLexerStream *ls, char c, YYSTYPE *res)
 		if (isdigit (gb_lexer_stream_peek (ls)))
 			/* Drop through to a float. */
 			return -1;
-		else if (!(isalnum (ls->lastc) || c == '$') &&
+		else if (!(isalnum ((guchar) ls->lastc) || c == '$') &&
 			 ls->lastc != ')')
 			return GB_SPACE_DOT;
 		else 
@@ -128,8 +128,9 @@ static int
 parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 {
 #ifdef GB_LEX_DEBUG
-	g_warning ("Parse basic %c", c);
+	g_warning ("Parse basic (0x%x) '%c'", c, c);
 #endif
+
 	switch (c) {
 
 	case '#': case ',':
@@ -146,7 +147,8 @@ parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 				c = gb_lexer_stream_getc (ls);
 				return GB_NE;
 			}
-		}
+		} else
+			return 0;
 
 	case '>':
 	case ':':
@@ -157,7 +159,8 @@ parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 				gb_lexer_stream_getc (ls);
 				return (c == '<' ) ? GB_LE : ((c == '>') ? GB_GE : GB_ARG_ASSIGN);
 			}
-		}
+		} else
+			return 0;
 
 		return c;
 	
@@ -184,7 +187,11 @@ parse_basic (YYSTYPE *res, GBLexerStream *ls, char c)
 	default:
 	{
 		int   tmp;
-		char *str = gb_lexer_stream_gets (ls, c);
+		char *str;
+
+		g_assert (!gb_lexer_stream_eof (ls));
+		
+		str = gb_lexer_stream_gets (ls, c);
 
 		/* Look for Remarks */
 		if (!g_strcasecmp (str, "Rem")) {
@@ -323,7 +330,7 @@ parse_project (YYSTYPE *res, GBLexerStream *ls, char c)
 int
 gb_lex (YYSTYPE *res, void *closure)
 {
-	GBParseData   *buf = closure;
+	GBParseData *buf = closure;
 
 	return gb_lex_real (res, buf->ls);
 }
@@ -335,23 +342,33 @@ gb_lex_real (gpointer r, GBLexerStream *ls)
 	gboolean line_continue;
 	char     c;
 
-	keep_looking :
-		if (gb_lexer_stream_eof (ls))
-			return 0;
-
+ keep_looking:
+	if (gb_lexer_stream_eof (ls))
+		return 0;
+	
 	if (ls->incr_line) {
 		gb_lexer_stream_line_inc (ls);
 		ls->incr_line = FALSE;
 	}
 
+	if (ls->first_symbol) {
+		int r = ls->first_symbol;
+
+		ls->first_symbol = 0;
+
+		return r;
+	}
+
 	ls->lastc = ls->c;
 
 	ls->c = c = gb_lexer_stream_getc (ls);
 
 	switch (c)
 	{
+	case '\0':
 	case ' ':
-	case '\t': goto keep_looking;
+	case '\t':
+		goto keep_looking;
 
 	case '\'':
 		while (!gb_lexer_stream_eof (ls)) {
@@ -451,6 +468,9 @@ gb_lex_real (gpointer r, GBLexerStream *ls)
 		case GB_PARSING_PROJECT:
 			r = parse_project (res, ls, c);
 			break;
+		default:
+			g_error ("Serious lexing error; unknown state %d", s);
+			break;
 		};
 
 		if (r == GB_KEEP_LOOKING)
@@ -529,7 +549,29 @@ gb_lexer_stream_state_set (GBLexerStream *ls, GBParsingState state)
 static void
 state_set (GBLexerStream *ls, GBParsingState state)
 {
-	ls->state = state;
+	switch (state) {
+/*	case GB_LEX_FILE:
+		ls->first_symbol = GB_LEXTYPE_FILE;
+		break;*/
+
+	case GB_PARSING_EXPR:
+		ls->first_symbol = GB_LEXTYPE_EXPR;
+		ls->state = GB_PARSING_BASIC;
+		break;
+
+	case GB_PARSING_STATEMENTS:
+		ls->first_symbol = GB_LEXTYPE_STATEMENTS;
+		ls->state = GB_PARSING_BASIC;
+		break;
+
+	case GB_PARSING_ASP:
+		ls->first_symbol = GB_LEXTYPE_ASP;
+		/* drop through */
+
+	default:
+		ls->state = state;
+		break;
+	}
 }
 
 gboolean
@@ -537,18 +579,20 @@ gb_lexer_is_string_char (GBLexerStream *ls, char c)
 {
 	switch (ls->state) {
 
+	case GB_PARSING_ASP:
 	case GB_PARSING_BASIC:
-		return isalnum (c) || c == '_' || c == '$';
+		return isalnum ((guchar) c) || c == '_' || c == '$';
 
 	case GB_PARSING_FORM: case GB_PARSING_CLASS:
-		return isalnum (c) || c == '_' || c == '$' || c == '^' ||
+		return isalnum ((guchar) c) || c == '_' || c == '$' || c == '^' ||
 			c == '(' || c == ')' || c == '.' ;
 
 	case GB_PARSING_PROJECT:
 		return (c != '=' && c != ']' && c != '\n' && c != '\r');
-				
+	default:
+		g_error ("Serious lexer string error state %d", ls->state);
+		break;
 	}
-	g_warning ("Serious lexer string error");
 	return FALSE;
 }
 
