@@ -14,6 +14,7 @@
 #include <libgb.h>
 #include <gb/gb-main.h>
 #include <gb/gb-eval.h>
+#include <gb/gb-form.h>
 #include <gb/gb-statement.h>
 #include <gb/gb-mmap-lex.h>
 
@@ -241,10 +242,26 @@ void
 gb_parse_data_destroy (const GBParseData * const_module)
 {
 	/* cast away const */
-	GBParseData * module = (GBParseData *) const_module;
+	GBParseData *module = (GBParseData *) const_module;
+	GSList      *l;
 
 	g_return_if_fail (module != NULL);
 
+	if (module->expr)
+		gb_expr_destroy (module->expr);
+	module->expr = NULL;
+
+
+	if (module->stmts)
+		gb_stmts_destroy (module->stmts);
+	module->stmts = NULL;
+
+
+	for (l = module->types; l; l = l->next)
+		gb_type_destroy (l->data);
+	g_slist_free (module->types);
+	module->types = NULL;
+
 	if (module->routines) {
 		g_hash_table_foreach_remove (module->routines,
 					     &cb_routine_destroy,
@@ -257,7 +274,16 @@ gb_parse_data_destroy (const GBParseData * const_module)
 		gb_var_dict_free (module->variables);
 	module->variables = NULL;
 
-	/* TODO : Free expressions, objrefs, and statements */
+	module->current_routine = NULL;
+
+	if (module->form)
+		gb_form_item_destroy (module->form);
+	module->form = NULL;
+
+	for (l = module->class; l; l = l->next)
+		gb_form_property_destroy (l->data);
+	g_slist_free (module->class);
+	module->class = NULL;
 }
 
 extern int gb_parse (void *);
@@ -292,6 +318,7 @@ gb_parse_stream (GBEvalContext *ec, GBLexerStream *ls)
 void
 gb_parse_data_end_form (GBParseData *module, GBFormItem *form)
 {
+	g_warning ("End form '%p' on module '%p'", form, module);
 	module->form = form;
 	gb_lexer_stream_state_set (module->ls, GB_PARSING_BASIC);
 }
@@ -309,6 +336,53 @@ gb_parse_data_start_form (GBParseData *module)
 	gb_lexer_stream_state_set (module->ls, GB_PARSING_FORM);
 }
 
+void
+gb_parse_data_set_expr (GBParseData  *module,
+			const GBExpr *expr)
+{
+	module->expr = expr;
+}
+
+void
+gb_parse_data_set_stmts (GBParseData *module,
+			 GSList      *stmts)
+{
+	module->stmts = g_slist_reverse (stmts);
+}
+
+void
+gb_parse_data_add_type (GBParseData  *module,
+			GBType       *type)
+{
+	g_return_if_fail (type != NULL);
+	g_return_if_fail (module != NULL);
+
+	module->types = g_slist_prepend (module->types, type);
+}
+
+gboolean
+gb_parse_data_add_var (GBParseData *parse_data,
+		       GBVar       *var)
+{
+	GBVar       *new_var   = NULL;
+	GHashTable **variables = (parse_data->current_routine != NULL)
+		? &parse_data->current_routine->variables
+		: &parse_data->variables;
+
+	if (!*variables)
+		*variables = gb_priv_new_hash ();
+
+	else if ((new_var = gb_priv_lookup (*variables, var->name))) {
+		g_warning ("%s : Already declared in this context",
+			   new_var->name);
+		return TRUE;
+	}
+
+	g_hash_table_insert (*variables, &var->name, var);
+
+	return FALSE;
+}
+
 void
 gb_init (void)
 {
