@@ -12,6 +12,7 @@
 #define GB_MAIN_H
 
 #include <gb/gb.h>
+#include <gb/gb-type.h>
 #include <gb/gb-expr.h>
 
 typedef enum { 
@@ -39,40 +40,44 @@ struct _GBRoutine {
 	GHashTable  *variables;
 };
 
-/* Variable */
-struct _GBVar {
-	gchar const *name;
-	gboolean     object;
-	char const  *type;
-	gboolean     is_array;
-	GSList      *indicees;
-};
-
 /* The GB file being parsed */
 struct _GBParseData {
 	/* The source of the source */
 	GBLexerStream *ls;
 
-	/* Set of routines declared within the file hashed by name */
-	GHashTable *routines;
-
-	/* Set of global variables hashed by name */
-	GHashTable *variables;
-
-	/* The current routine */
-	GBRoutine  *current_routine;
-
 	/* An evaluation context for const_exprs & exceptions */
 	GBEvalContext *ec;
 
-	/* Any associated form data */
-	GBFormItem    *form;
+	/* Single expression */
 
-	/* Any associated class data */
-	GSList        *class;
+		const GBExpr *expr;
 
-	/* Support nested with statements */
-	int with_depth;
+	/* Block of statements */
+
+		GSList       *stmts;
+
+	/* Elements for full parsing */
+
+		/* All new types declared in this scope GBType *'s */
+		GSList       *types;
+
+		/* Set of routines declared within the file hashed by name */
+		GHashTable   *routines;
+	
+		/* Set of global variables hashed by name */
+		GHashTable   *variables;
+	
+		/* The current routine */
+		GBRoutine    *current_routine;
+		
+		/* Any associated form data */
+		GBFormItem    *form;
+	
+		/* Any associated class data */
+		GSList        *class;
+	
+		/* Support nested with statements */
+		int with_depth;
 };
 
 /* Call before doing anything  */
@@ -82,28 +87,41 @@ void             gb_shutdown      (void);
 
 /* Return TRUE on error */
 gboolean         gb_routine_start   (GBParseData        *module,
-				     char const         *name,
+				     const char         *name,
 				     GSList             *args,
-				     gboolean const      is_function,
+				     gboolean            is_function,
 				     GBClassPropertyType prop_type);
 
 GBRoutine const *gb_routine_finish  (GBParseData *module,
 				     gboolean  is_private,
 				     gboolean  is_function,
 				     GSList   *body);
-void             gb_routine_print   (FILE *sink, GBRoutine const *routine);
+void             gb_routine_print   (FILE *sink, const GBRoutine *routine);
 
-GBVar           *gb_var_lookup      (GBParseData *module, char const *const name);
+GBVar           *gb_var_lookup      (GBParseData *module, const char *name);
 
 
-void             gb_parse_data_start_form (GBParseData *module);
-void             gb_parse_data_end_form   (GBParseData *module,
-					   GBFormItem *form);
+void             gb_parse_data_start_form (GBParseData  *module);
+void             gb_parse_data_end_form   (GBParseData  *module,
+					   GBFormItem   *form);
 
-void             gb_parse_data_end_class  (GBParseData *module,
-					   GSList      *class);
+void             gb_parse_data_end_class  (GBParseData  *module,
+					   GSList       *class);
 
-void  gb_module_with_depth_inc (GBParseData *module, GBExpr const *base_obj);
+void             gb_parse_data_set_expr   (GBParseData  *module,
+					   const GBExpr *expr);
+
+void             gb_parse_data_set_stmts  (GBParseData  *module,
+					   GSList       *stmts);
+
+void             gb_parse_data_add_type   (GBParseData  *module,
+					   GBType       *type);
+
+gboolean         gb_parse_data_add_var    (GBParseData  *module,
+					   GBVar        *var);
+
+void             gb_module_with_depth_inc (GBParseData  *module,
+					   const GBExpr *base_obj);
 
 
 struct _GBIndex {
@@ -113,11 +131,4 @@ struct _GBIndex {
 
 GBIndex *gb_index_new (const GBExpr *min, const GBExpr *max);
 
-gboolean gb_decl_var  (GBParseData *parse_data,
-		       const char  *name,
-		       gboolean     obj,
-		       gboolean     is_array,
-		       GSList      *indicees,
-		       const char  *type);
-
 #endif /* GB_MAIN_H */
