@@ -56,7 +56,7 @@ s_gets (GBLexerStream *ls, char c)
         GBMMapStream *ms = GB_MMAP_STREAM (ls);
 
 	if (s_eof (ls))
-	        return NULL;
+	        return g_strdup ("");
 
 	else {
 	        const char *s = ms->cur;
