@@ -42,6 +42,7 @@ GtkType gb_type_single;
 GtkType gb_type_double;
 GtkType gb_type_string;
 GtkType gb_type_boolean;
+GtkType gb_type_list;
 
 GBValue *
 gb_value_new_empty (void)
@@ -346,7 +347,6 @@ gb_value_copy (GBEvalContext *ec, const GBValue *v)
 	GBValue *val;
 
 	g_return_val_if_fail (v != NULL, NULL);
-	g_return_val_if_fail (ec != NULL, NULL);
 
 	val = g_new (GBValue, 1);
 
@@ -401,7 +401,7 @@ gb_value_copy_byval (GBEvalContext *ec, const GBValue *v)
 	if (v->gtk_type != gb_gtk_type_from_value (GB_VALUE_OBJECT))
 		return gb_value_copy (ec, v);
 	else
-		return gb_eval_exception_fire (ec, "Object copy unimplemented");
+		return gb_eval_exception_fire (ec, _("Object copy unimplemented"));
 }
 
 void
@@ -1090,7 +1090,7 @@ gb_value_promote (GBEvalContext *ec,
 	if (ret)
 		return ret;
 
-	return gb_eval_exception_firev (ec, "(gb_value_promote) Can't promote %s to %s",
+	return gb_eval_exception_firev (ec, _("(gb_value_promote) Can't promote %s to %s"),
 					gtk_type_name (gb_gtk_type_from_value (from)),
 					gtk_type_name (to));
 }
@@ -1332,6 +1332,7 @@ gb_value_init (void)
 	gb_type_double  = builtin_types [GB_VALUE_DOUBLE].created_type;
 	gb_type_string  = builtin_types [GB_VALUE_STRING].created_type;
 	gb_type_boolean = builtin_types [GB_VALUE_BOOLEAN].created_type;
+	gb_type_list    = builtin_types [GB_VALUE_LIST].created_type;
 
 	builtin_types [GB_VALUE_OBJECT].created_type =
 		gb_object_get_type ();
