@@ -13,6 +13,10 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+/* Putting these here sucks */
+#include <libgnome/gnome-defs.h>
+#include <libgnome/gnome-i18n.h>
+
 /* gb-value.h: structures */
 typedef struct _GBValue      GBValue;
 typedef struct _InternalDec  InternalDec;
@@ -67,6 +71,10 @@ typedef struct _GBIndex     GBIndex;
 typedef struct _GBStatement  GBStatement;
 typedef struct _GBSelectCase GBSelectCase;
 
+/* gb-type.h */
+typedef struct _GBType       GBType;
+typedef struct _GBTypeElem   GBTypeElem;
+
 /* gb-lex.h */
 typedef struct _GBLexerStream      GBLexerStream;
 typedef struct _GBLexerStreamClass GBLexerStreamClass;
