@@ -1,4 +1,3 @@
-
 /*
  * GNOME Basic Array support
  *
@@ -35,7 +34,7 @@ array_deref (GBRunEvalContext *ec,
 
 	if (g_slist_length (a->indicees) !=
 	    g_slist_length (ref->parms))
-		return gbrun_exception_firev (ec, "Too many / few array indicees");
+		return gbrun_exception_firev (ec, _("Too many / few array indicees"));
 
 	i      = a->indicees;
 	data   = a->data;
@@ -59,8 +58,8 @@ array_deref (GBRunEvalContext *ec,
 		
 		if (into < r->min ||
 		    into > r->max)
-			return gbrun_exception_firev (ec, "Out of bounds array index "
-						      "%d !<= %d !<= %d", r->min, into, r->max);
+			return gbrun_exception_firev (ec, _("Out of bounds array index "
+						      "%d !<= %d !<= %d"), r->min, into, r->max);
 
 		pos    = (GBValue **)&(data [into - r->min]);
 		data   = data [into - r->min];
@@ -82,7 +81,7 @@ array_deref (GBRunEvalContext *ec,
 
 	if (assign) {
 		if (!pos)
-			return gbrun_exception_firev (ec, "Wierd, nowhere  to assign");
+			return gbrun_exception_firev (ec, _("Wierd, nowhere  to assign"));
 		if (*pos)
 			gb_value_destroy (*pos);
 
@@ -93,7 +92,7 @@ array_deref (GBRunEvalContext *ec,
 
 	if (!data || (!GB_IS_AN_OBJECT (((GBValue *)data)->gtk_type) &&
 		      !GB_IS_A_FUNDAMENTAL (((GBValue *)data)->gtk_type)))
-		return gbrun_exception_firev (ec, "Serious internal error in array dereference");
+		return gbrun_exception_firev (ec, _("Serious internal error in array dereference"));
 
 	return gb_value_copy (GB_EVAL_CONTEXT (ec), (GBValue *)data);
 }
@@ -228,13 +227,6 @@ array_new_for_type (GBRunEvalContext *ec, const char *type)
 
 	a->content_type = gb_gtk_type_from_name (type);
 
-	if (a->content_type == GB_VALUE_EMPTY) {
-		gbrun_exception_firev (ec, "Invalid type '%s'", type);
-		gtk_object_destroy (GTK_OBJECT (a));
-
-		return NULL;
-	}
-
 	return a;
 }
 
@@ -251,6 +243,8 @@ gbrun_array_new (GBRunEvalContext *ec,
 
 	a = array_new_for_type (ec, var->type);
 	
+	g_return_val_if_fail (a != NULL, NULL);
+
 	/* Evaluate indicees */
 	a->indicees = NULL;
 	for (l = var->indicees; l; l = l->next) {
