@@ -61,6 +61,8 @@ gbrun_eval_context_construct (GBRunEvalContext  *ec,
 
 	gbrun_files_init (ec);
 
+	gbrun_eval_context_set_module (ec, module_name);
+
 	return ec;
 }
 
@@ -87,6 +89,13 @@ gbrun_eval_context_destroy (GtkObject *o)
 		gtk_object_unref (GTK_OBJECT (ec->stack));
 		ec->stack = NULL;
 		gbrun_files_clean (ec);
+
+		if (ec->me)
+			gb_value_destroy (ec->me);
+
+		g_free (ec->module);
+
+		while (gbrun_eval_context_proj_pop (ec));
 	}
 
 	GTK_OBJECT_CLASS (gbrun_eval_context_parent)->destroy (o);
@@ -103,7 +112,8 @@ fire (GBEvalContext *ec, const char *txt)
 	g_return_if_fail (GBRUN_IS_EVAL_CONTEXT (ec));
 
 	stack = gbrun_stack_dump (GBRUN_EVAL_CONTEXT (ec)->stack);
-	msg = g_strconcat (txt, " in function ", stack [0], NULL);
+	msg = g_strconcat (txt, " in module ",
+			   GBRUN_EVAL_CONTEXT (ec)->module, NULL);
 
 	for (i = 1; stack [i]; i++) {
 		char *tmp = msg;
@@ -287,3 +297,21 @@ gbrun_eval_as (GBRunEvalContext  *ec,
 
 	return ans;
 }
+
+char *
+gbrun_eval_context_get_module (GBRunEvalContext *ec)
+{
+	g_return_val_if_fail (GBRUN_IS_EVAL_CONTEXT (ec), NULL);
+
+	return g_strdup (ec->module);
+}
+
+void
+gbrun_eval_context_set_module (GBRunEvalContext *ec,
+			       const char       *module)
+{
+	g_return_if_fail (GBRUN_IS_EVAL_CONTEXT (ec));
+
+	g_free (ec->module);
+	ec->module = g_strdup (module);
+}
