@@ -35,6 +35,8 @@ struct _GBRunEvalContext {
 
 	GBValue          *me;
 
+	char             *module;
+
 	/* Runtime execution state storage */
 	GBRunFileHandle  *file_handles;
 
@@ -48,35 +50,39 @@ struct _GBRunEvalContextClass {
 	GBEvalContextClass klass;
 };
 
-GtkType           gbrun_eval_context_get_type  (void);
+GtkType           gbrun_eval_context_get_type   (void);
 
-GBRunEvalContext *gbrun_eval_context_construct (GBRunEvalContext  *ec,
-						const char        *module_name,
-						GBRunSecurityFlag  flags);
+GBRunEvalContext *gbrun_eval_context_construct  (GBRunEvalContext  *ec,
+						 const char        *module_name,
+						 GBRunSecurityFlag  flags);
 
-GBRunEvalContext *gbrun_eval_context_new       (const char        *module_name,
-						GBRunSecurityFlag  flags);
-GBValue          *gbrun_eval_as                (GBRunEvalContext  *ec,
-						const GBExpr      *expr,
-						GBValueType        ret_type);
+GBRunEvalContext *gbrun_eval_context_new        (const char        *module_name,
+						 GBRunSecurityFlag  flags);
 
-GBObject         *gbrun_eval_context_me_get    (GBRunEvalContext *ec);
-void              gbrun_eval_context_me_set    (GBRunEvalContext *ec,
-						GBObject         *obj);
+char             *gbrun_eval_context_get_module (GBRunEvalContext  *ec);
+void              gbrun_eval_context_set_module (GBRunEvalContext  *ec,
+						 const char        *module);
 
-GBRunProject     *gbrun_eval_context_proj_get  (GBRunEvalContext *ec);
-void              gbrun_eval_context_proj_push (GBRunEvalContext *ec,
-						GBRunProject     *obj);
-GBRunProject     *gbrun_eval_context_proj_pop  (GBRunEvalContext *ec);
+GBValue          *gbrun_eval_as                 (GBRunEvalContext  *ec,
+						 const GBExpr      *expr,
+						 GBValueType        ret_type);
+
+GBObject         *gbrun_eval_context_me_get     (GBRunEvalContext *ec);
+void              gbrun_eval_context_me_set     (GBRunEvalContext *ec,
+						 GBObject         *obj);
+
+GBRunProject     *gbrun_eval_context_proj_get   (GBRunEvalContext *ec);
+void              gbrun_eval_context_proj_push  (GBRunEvalContext *ec,
+						 GBRunProject     *obj);
+GBRunProject     *gbrun_eval_context_proj_pop   (GBRunEvalContext *ec);
 
 /* convenience wrappers */
-gboolean          gbrun_eval_context_exception (GBRunEvalContext *ec);
+gboolean          gbrun_eval_context_exception  (GBRunEvalContext *ec);
 #define           gbrun_eval_context_get_text(ec) (gb_eval_context_get_text (GB_EVAL_CONTEXT (ec)))
-GBValue          *gbrun_exception_fire         (GBRunEvalContext *ec,
-						const char *txt);
-GBValue          *gbrun_exception_firev        (GBRunEvalContext *ec,
-						const char *format, ...);
-
 
+GBValue          *gbrun_exception_fire          (GBRunEvalContext *ec,
+						 const char       *txt);
+GBValue          *gbrun_exception_firev         (GBRunEvalContext *ec,
+						 const char       *format, ...);
 
 #endif /* GBRUN_EVAL_H */
