@@ -137,7 +137,7 @@ setup_vars (gpointer key, gpointer value, gpointer user_data)
 		t = gb_gtk_type_from_name (var->type);
 		if (!t)
 			gb_eval_exception_firev (GB_EVAL_CONTEXT (c->ec),
-						 "Unknown type '%s'", var->type);
+						 _("Unknown type '%s'"), var->type);
 		else
 			val = gb_value_new_default (GB_EVAL_CONTEXT (c->ec), t);
 	}
@@ -255,10 +255,7 @@ parse_def (const char       *str,
 	def_val = gb_value_promote (GB_EVAL_CONTEXT (ec), to, tmp);
 	gb_value_destroy (tmp);
 
-	if (gbrun_eval_context_exception (ec))
-		return NULL;
-
-	gtk_object_destroy (GTK_OBJECT (ec));
+	gtk_object_unref (GTK_OBJECT (ec));
 
 	return def_val;
 }
@@ -628,11 +625,14 @@ gbrun_method_invoke_arg (GBRunEvalContext *ec, GBRunObject      *obj,
 	len = g_slist_length (func->parms);
 
 	if (len < m->min_args)
-		return gbrun_exception_firev (ec, "Too few args to %s %d expected %d given",
-					    func->name, m->min_args, len);
+		return gbrun_exception_firev (
+			ec, _("Too few args to %s %d expected %d given"),
+			func->name, m->min_args, len);
+
 	if (len > m->max_args)
-		return gbrun_exception_firev (ec, "Too many args to %s %d expected %d given",
-					    func->name, m->max_args, len);
+		return gbrun_exception_firev (
+			ec, _("Too many args to %s %d expected %d given"),
+			func->name, m->max_args, len);
 	
 	vals = g_new (GBValue *, m->max_args + 1);
 
@@ -693,46 +693,18 @@ gbrun_method_invoke_var (GBRunEvalContext *ec, GBRunObject      *obj,
 	len = g_slist_length (func->parms);
 
 	if (len < m->min_args)
-		return gbrun_exception_firev (ec, "Too few args to %s %d expected %d given",
-					    func->name, m->min_args, len);
+		return gbrun_exception_firev (
+			ec, _("Too few args to %s %d expected %d given"),
+			func->name, m->min_args, len);
 
 	return m->handler.var (ec, obj, func->parms); 
 }
 
-static GBValue *
-value_from_var (GBRunEvalContext *ec,
-		GBVar            *var)
-{
-	GBValue *val;
-
-	if (var->is_array)
-		val = gb_value_new_object (GB_OBJECT (gbrun_array_new (ec, var)));
-	else {
-		GtkType t;
-
-		if (var->object) {
-			t = gb_gtk_type_from_name (var->type);
-			val = gb_value_new_object (gtk_type_new (t));
-
-		} else {
-			t = gb_gtk_type_from_name (var->type);
-
-			if (!t)
-				gb_eval_exception_firev (GB_EVAL_CONTEXT (ec),
-							 "Unknown type '%s'", var->type);
-			else
-				val = gb_value_new_default (GB_EVAL_CONTEXT (ec), t);
-		}
-	}
-
-	return val;
-}
-
 static void
 stack_setup_vars (gpointer key, gpointer value, gpointer user_data)
 {
 	GBVar   *var = value;
-	GBValue *val = value_from_var (user_data, var);
+	GBValue *val = gbrun_value_default_from_var (user_data, var);
 
 /*	g_warning ("Adding variable '%s' at stack level %d", var->name,
 	g_list_length (ec->stack->level));*/
@@ -757,10 +729,10 @@ gbrun_method_invoke_vb (GBRunEvalContext *ec, GBRunObject      *obj,
 	len = g_slist_length (func->parms);
 
 	if (len < m->min_args)
-		return gbrun_exception_firev (ec, "Too few args to %s %d expected %d given",
+		return gbrun_exception_firev (ec, _("Too few args to %s %d expected %d given"),
 					    func->name, m->min_args, len);
 	if (len > m->max_args)
-		return gbrun_exception_firev (ec, "Too many args to %s %d expected %d given",
+		return gbrun_exception_firev (ec, _("Too many args to %s %d expected %d given"),
 					    func->name, m->max_args, len);
 
 	/* Set 'Me' up */
@@ -831,7 +803,7 @@ gbrun_method_invoke_vb (GBRunEvalContext *ec, GBRunObject      *obj,
 		if (m->is_sub)
 			ans = gb_value_new_empty ();
 		else
-			gbrun_exception_firev (ec, "No return value for function '%s'",
+			gbrun_exception_firev (ec, _("No return value for function '%s'"),
 					       func->name);
 	} else
 		ans = gbrun_value_copy (ec, *ans_var);
@@ -887,7 +859,7 @@ chain_assign_to_value (GBEvalContext  *ec,
 		if (!try_assign)
 			gbrun_exception_firev (
 				GBRUN_EVAL_CONTEXT (ec),
-				"Cannot use parameters on '%s'", ref->name);
+				_("Cannot use parameters on '%s'"), ref->name);
 	}
 	return FALSE;
 }
@@ -932,7 +904,7 @@ gbrun_object_assign (GBEvalContext  *ec,
 		if (!try_assign)
 			gbrun_exception_firev (
 				GBRUN_EVAL_CONTEXT (ec),
-				"No writeable property '%s' on object '%s'",
+				_("No writeable property '%s' on object '%s'"),
 				ref->name, gbrun_object_name (GBRUN_OBJECT (object)));
 		return FALSE;
 	}
@@ -967,7 +939,7 @@ chain_deref_to_value (GBEvalContext  *gb_ec,
 			gb_ec, val->v.obj, &newref, try_deref);
 	} else
 		gb_eval_exception_firev (
-			gb_ec, "Cannot use parameters on '%s'",
+			gb_ec, _("Cannot use parameters on '%s'"),
 			ref->name);
 
 	gb_value_destroy (val);
@@ -1015,7 +987,7 @@ gbrun_object_deref (GBEvalContext  *gb_ec,
 		if (ec->flags & m->mask) {
 			if (!try_deref)
 				gbrun_exception_firev (
-					ec, "Security block on function '%s'",
+					ec, _("Security block on function '%s'"),
 					ref->name);
 			return NULL;
 		}
@@ -1058,7 +1030,7 @@ gbrun_object_deref (GBEvalContext  *gb_ec,
 			else {
 				if (!try_deref)
 					gbrun_exception_firev (
-						ec, "Too many arguments to '%s'",
+						ec, _("Too many arguments to '%s'"),
 						ref->name);
 				if (val)
 					gb_value_destroy (val);
@@ -1081,7 +1053,7 @@ gbrun_object_deref (GBEvalContext  *gb_ec,
 		if (!prop) {
 			if (!try_deref)
 				gbrun_exception_firev (
-					ec, "No readable property '%s' on object '%s'",
+					ec, _("No readable property '%s' on object '%s'"),
 					ref->name, gbrun_object_name (GBRUN_OBJECT (obj)));
 			return NULL;
 		}
@@ -1126,19 +1098,23 @@ gbrun_object_instance_init (GBRunObject      *object,
 	object->priv->vars = gbrun_stack_level_new ("Object vars");
 
 /*	g_warning ("Instance init '%s' ( '%d' vars )",
-		   gtk_type_name (GTK_OBJECT_CLASS (klass)->type),
-		   g_slist_length (klass->priv->variables));*/
+	gtk_type_name (GTK_OBJECT_CLASS (klass)->type),
+	g_slist_length (klass->priv->variables));*/
 
 	/* Setup the object's data */
 	for (l = klass->priv->variables; l; l = l->next) {
 
 		GBVar   *var = l->data;
-		GBValue *val = value_from_var (ec, var);
+		GBValue *val = gbrun_value_default_from_var (ec, var);
 
-/*		g_warning ("Adding instance object variable '%s'", var->name);*/
+		if (!val) {
+			g_warning ("Can't create default for '%s'", var->name);
+		} else {
+/*			g_warning ("Adding instance object variable '%s'", var->name);*/
 
-		gbrun_stack_level_add (ec, object->priv->vars,
-				       var->name, val);
+			gbrun_stack_level_add (ec, object->priv->vars,
+					       var->name, val);
+		}
 	}
 
 	gtk_object_unref (GTK_OBJECT (ec));
@@ -1211,6 +1187,14 @@ gbrun_object_get_type (void)
 	return object_type;	
 }
 
+GBRunObject *
+gbrun_object_new (GBRunObjectClass *klass)
+{
+	g_return_val_if_fail (GBRUN_IS_OBJECT_CLASS (klass), NULL);
+
+	return gtk_type_new (GTK_OBJECT_CLASS (klass)->type);
+}
+
 GtkType
 gbrun_object_subclass (GtkType           parent,
 		       const char       *vb_name,
