@@ -22,19 +22,19 @@
 typedef struct _GBRunProjectPriv GBRunProjectPriv;
 
 struct _GBRunProject {
-	GtkObject            object;
+	GBObject          object;
 
-	GBRunProjectPriv    *priv;
+	GBRunProjectPriv *priv;
 };
 
 struct _GBRunProjectClass {
-	GtkObjectClass     klass;
+	GBObjectClass     klass;
 };
 
 GtkType           gbrun_project_get_type          (void);
-const GSList     *gbrun_project_get_objects       (GBRunProject *project);
 void              gbrun_project_register_object   (GBRunProject *project,
-						   GBRunObject  *object);
+						   GBRunObject  *object,
+						   const char   *name);
 void              gbrun_project_deregister_object (GBRunProject *project,
 						   GBRunObject  *object);
 
