@@ -1,5 +1,4 @@
-
-/*
+/**
  * GNOME Basic Stack
  *
  * Author:
@@ -28,8 +27,8 @@ struct _GBRunStackLevel {
 
 static GBRunVar *
 gbrun_var_new (GBRunEvalContext *ec,
-	     const char       *name,
-	     const GBValue    *val)
+	       const char       *name,
+	       const GBValue    *val)
 {
 	GBRunVar *var = g_new (GBRunVar, 1);
 
@@ -154,7 +153,7 @@ gbrun_stack_level_add (GBRunEvalContext *ec,
 		       const char       *name,
 		       const GBValue    *val)
 {
-	GBRunVar        *v;
+	GBRunVar *v;
 
 	v = gbrun_var_new (ec, name, val);
 
@@ -244,8 +243,7 @@ gbrun_stack_set (GBRunEvalContext *ec,
 	GBValue **val;
 
 	if (!g_strcasecmp (name, "Me")) {
-		g_warning ("Serious error setting 'Me' and no"
-			   " way to flag it: ug!");
+		gbrun_exception_fire (ec, _("Serious error setting 'Me'"));
 		return;
 	}
 
@@ -330,7 +328,7 @@ gbrun_stack_assign (GBEvalContext  *ec,
 			if (!try_assign)
 				gbrun_exception_firev (
 					GBRUN_EVAL_CONTEXT (ec),
-					"No array or collection %s", ref->name);
+					_("No array or collection %s"), ref->name);
 
 			return FALSE;
 
@@ -346,7 +344,7 @@ gbrun_stack_assign (GBEvalContext  *ec,
 			if (!try_assign)
 				gbrun_exception_firev (
 					GBRUN_EVAL_CONTEXT (ec),
-					"Variable %s is not a method", ref->name);
+					_("Variable %s is not a method"), ref->name);
 
 			return FALSE;
 		}
@@ -372,7 +370,7 @@ gbrun_stack_deref (GBEvalContext  *gb_ec,
 			return NULL;
 		else
 			return gbrun_exception_firev (
-				ec, "No such variable %s", ref->name);
+				ec, _("No such variable %s"), ref->name);
 	}
 
 	if (ref->method || ref->parms) {
@@ -389,7 +387,7 @@ gbrun_stack_deref (GBEvalContext  *gb_ec,
 				return NULL;
 			else
 				return gbrun_exception_firev (
-					ec, "Variable %s is not a method", ref->name);
+					ec, _("Variable %s is not a method"), ref->name);
 		}
 	} else
 		ret = gbrun_value_copy (ec, *val);
