@@ -45,7 +45,9 @@ gbrun_frame_dump (GBRunFrame *rf, const char *type)
 #endif
 
 static void
-gbrun_frame_stmts_push (GBRunEvalContext *ec, GSList *stmts)
+gbrun_frame_stmts_push_full (GBRunEvalContext *ec,
+			     GSList           *stmts,
+			     gboolean          eval_call)
 {
 	GBRunFrame    *rf = gbrun_stack_frame (ec->stack);
 	GBRunSubFrame *sf = g_new0 (GBRunSubFrame, 1);
@@ -63,12 +65,19 @@ gbrun_frame_stmts_push (GBRunEvalContext *ec, GSList *stmts)
 	sf->stmts  = stmts;
 	sf->init   = TRUE;
 	sf->pushed = TRUE;
+	sf->eval_call = eval_call;
 
 #ifdef STMT_DEBUG
 	gbrun_frame_dump (rf, "after push");
 #endif
 }
 
+static void
+gbrun_frame_stmts_push (GBRunEvalContext *ec, GSList *stmts)
+{
+	gbrun_frame_stmts_push_full (ec, stmts, FALSE);
+}
+
 static void
 gbrun_frame_crop_to (GBRunEvalContext *ec, guint depth)
 {
@@ -119,8 +128,15 @@ gbrun_frame_stmt_next (GBRunEvalContext *ec, gboolean *init)
 
 	if (!sf->stmts) {
 		rf->cur = sf->parent;
-		g_free (sf);
+
+		/* gbrun_stmt_evaluate was re-entered */
+		if (sf->eval_call) {
+			g_free (sf);
+			return NULL;
+		}
 		
+		g_free (sf);
+
 		if (rf->cur) {
 			rf->cur->init   = FALSE;
 			rf->cur->pushed = TRUE;
@@ -210,8 +226,8 @@ handle_stmt_goto (GBRunEvalContext *ec, const char *label)
 	 * is more interesting.
 	 */
 	if (depth > i) {
-		gbrun_exception_firev (ec, "Can't goto label '%s' at depth %d, "
-				       "when we are at depth %d", label, depth, i);
+		gbrun_exception_firev (ec, _("Can't goto label '%s' at depth %d, \
+				       when we are at depth %d"), label, depth, i);
 		return FALSE;
 	}
 
@@ -221,7 +237,7 @@ handle_stmt_goto (GBRunEvalContext *ec, const char *label)
 	return TRUE;
 	
  stmt_goto_err:
-	gbrun_exception_firev (ec, "Can't find label '%s'", label);
+	gbrun_exception_firev (ec, _("Can't find label '%s'"), label);
 	return FALSE;
 }
 
@@ -238,7 +254,7 @@ gbrun_stmt_assign (GBRunEvalContext *ec,
 	gb_expr_print (stdout, rexpr);*/
 
 	if (lexpr->type != GB_EXPR_OBJREF) {
-		gbrun_exception_fire (ec, "Duff lvalue");
+		gbrun_exception_fire (ec, _("Duff lvalue"));
 		return FALSE;
 	}
 
@@ -262,7 +278,7 @@ gbrun_stmt_set (GBRunEvalContext *ec, const GBStatement *stmt)
 	g_return_val_if_fail (stmt->parm.set.objref != NULL, FALSE);
 
 	if (stmt->parm.set.objref->type != GB_EXPR_OBJREF) {
-		gbrun_exception_fire (ec, "Reference must be to an object in Set");
+		gbrun_exception_fire (ec, _("Reference must be to an object in Set"));
 		return FALSE;
 	}
 
@@ -650,7 +666,7 @@ gbrun_stmt_evaluate (GBRunEvalContext *ec, const GBStatement *stmt, gboolean ini
 	case GBS_DO:
 
 	default:
-		gbrun_exception_fire (ec, "Unhandled statement");
+		gbrun_exception_fire (ec, _("Unhandled statement"));
 		return FALSE;
 	}
 
@@ -669,7 +685,7 @@ gbrun_stmts_evaluate (GBRunEvalContext *ec, GSList *stmts)
 	if (!stmts)
 		return TRUE;
 
-	gbrun_frame_stmts_push (ec, stmts);
+	gbrun_frame_stmts_push_full (ec, stmts, TRUE);
 	rf->func_root = stmts;
 
 	while ((stmt = gbrun_frame_stmt_next (ec, &init))) {
@@ -683,6 +699,7 @@ gbrun_stmts_evaluate (GBRunEvalContext *ec, GSList *stmts)
 			
 			if      (ec->on_error.type == GB_ON_ERROR_FLAG)
 				break;
+
 			else if (ec->on_error.type == GB_ON_ERROR_GOTO) {
 				/* 0 is a special case apparently */
 				if (!strcmp (ec->on_error.label, "0"))
