@@ -33,4 +33,11 @@ GBValue      *gbrun_project_invoke   (GBRunEvalContext *ec,
 
 GSList       *gbrun_project_fn_names (GBRunProject     *proj);
 
+void          gbrun_exec_str         (GBRunEvalContext *ec,
+				      GBRunObject      *opt_object,
+				      const char       *basic_string);
+
+GBValue      *gbrun_eval_str         (GBRunEvalContext *ec,
+				      GBRunObject      *opt_object,
+				      const char       *basic_string);
 #endif
