@@ -13,6 +13,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
+#include <gbrun/libgbrun.h>
 #include <gbrun/gbrun.h>
 #include <gbrun/gbrun-value.h>
 #include <gbrun/gbrun-eval.h>
@@ -32,7 +33,7 @@ gbrun_func_vartype (GBRunEvalContext *ec,
 		    GBValue         **args)
 {
 	if (!args [0])
-		return gbrun_exception_firev (ec, "No argument");
+		return gbrun_exception_firev (ec, _("No argument"));
 
 	return gb_value_new_int (gb_value_from_gtk_type (args [0]->gtk_type));
 }
@@ -51,7 +52,7 @@ gbrun_func_filelen (GBRunEvalContext *ec,
 	name = args [0]->v.s->str;
 
 	if (stat (name, &buf))
-		return gbrun_exception_firev (ec, "FileLen error on %s", name);
+		return gbrun_exception_firev (ec, _("FileLen error on %s"), name);
 	
 	return gb_value_new_long (buf.st_size);
 }
@@ -80,8 +81,8 @@ gbrun_sub_print (GBRunEvalContext *ec,
 
 static GBValue *
 gbrun_sub_array (GBRunEvalContext *ec,
-	       GBRunObject      *object,
-	       GSList           *expr)
+		 GBRunObject      *object,
+		 GSList           *expr)
 {
 	GBObject *a;
 	GSList   *vals = NULL;
@@ -151,6 +152,47 @@ gbrun_func_isobject (GBRunEvalContext *ec,
 	return gb_value_new_boolean (TRUE);
 }
 
+static GBValue *
+gbrun_sub_call_by_name (GBRunEvalContext *ec,
+			GBRunObject      *object,
+			GBValue        **args)
+{
+	GBObjRef ref;
+
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+
+	ref.method = TRUE;
+	ref.name   = args [0]->v.s->str;
+	ref.parms  = NULL;
+
+	return gbrun_objref_deref (ec, GB_OBJECT (object), &ref, TRUE);
+}
+
+static GBValue *
+gbrun_func_eval (GBRunEvalContext *ec,
+		 GBRunObject      *object,
+		 GBValue         **args)
+{
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+
+	return gbrun_eval_str (ec, object, args [0]->v.s->str);
+}
+
+static GBValue *
+gbrun_sub_execute (GBRunEvalContext *ec,
+		   GBRunObject      *object,
+		   GBValue         **args)
+{
+	GB_IS_VALUE (ec, args [0], GB_VALUE_STRING);
+
+	gbrun_exec_str (ec, object, args [0]->v.s->str);
+
+	if (gbrun_eval_context_exception (ec))
+		return NULL;
+
+	return gb_value_new_empty ();
+}
+
 void
 gba_func_register (GBEvalContext *ec)
 {
@@ -159,7 +201,7 @@ gba_func_register (GBEvalContext *ec)
 
 	gba_object = gtk_type_new (
 		gbrun_object_subclass_simple (GBRUN_TYPE_OBJECT, "vba"));
-	gbrun_global_add (GB_OBJECT (gba_object));
+	gbrun_global_add (GB_OBJECT (gba_object), "vba");
 
 	gba = GBRUN_OBJECT_GET_CLASS (gba_object);
 
@@ -193,15 +235,26 @@ gba_func_register (GBEvalContext *ec)
 	gbrun_object_add_method_arg (gba, "func;isobject;expression,variant;boolean;n",
 				     gbrun_func_isobject);
 
-        gbrun_object_add_method_var (gba, "sub;array;...;n",  gbrun_sub_array);
+        gbrun_object_add_method_var (gba, "sub;array;...;n",
+				     gbrun_sub_array);
+
+        gbrun_object_add_method_arg (gba, "sub;callbyname;name,string;n",
+				     gbrun_sub_call_by_name);
+
+	/* Possibly only valid for vbscript etc. */
+        gbrun_object_add_method_arg (gba, "func;eval;basic,string;variant;n",
+				     gbrun_func_eval);
+
+        gbrun_object_add_method_arg (gba, "sub;execute;name,string;n",
+				     gbrun_sub_execute);
 
 	gba_object = gtk_type_new (
 		gbrun_object_subclass_simple (GBRUN_TYPE_OBJECT, "Debug"));
-	gbrun_global_add (GB_OBJECT (gba_object));
+	gbrun_global_add (GB_OBJECT (gba_object), "debug");
 
 	gba = GBRUN_OBJECT_GET_CLASS (gba_object);
 
-	gbrun_object_add_method_var (gba, "sub;print;...;n",  gbrun_sub_print);
+	gbrun_object_add_method_var (gba, "sub;print;...;n", gbrun_sub_print);
 }
 
 void
