@@ -167,7 +167,7 @@ gba_interaction_register (GBEvalContext *ec)
 
 	gba_object = gtk_type_new (
 		gbrun_object_subclass_simple (GBRUN_TYPE_OBJECT, ITEM_NAME));
-	gbrun_global_add (GB_OBJECT (gba_object));
+	gbrun_global_add (GB_OBJECT (gba_object), "interaction");
 
 	gba = GBRUN_OBJECT_GET_CLASS (gba_object);
 
