@@ -110,7 +110,7 @@ cmdbutton_setarg (GBRunEvalContext *ec,
 		gtk_window_set_default (button->item.form->window, button->item.widget);*/
 		return TRUE;
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("cmdbutton: Unhandled property '%d'", property);
 		return FALSE;
 	}
 }
@@ -146,7 +146,7 @@ cmdbutton_getarg (GBRunEvalContext *ec,
 		return gb_value_new_boolean (GTK_WIDGET_RECEIVES_DEFAULT (bwidget));
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("cmdbutton: Unhandled property '%d'", property);
 		break;
 	}
 
