@@ -20,6 +20,8 @@ enum {
 	TOP,
 	LEFT,
 
+	VISIBLE,
+
 	TABINDEX,
 
 	FORE_COLOR,
@@ -84,6 +86,13 @@ form_item_setarg (GBRunEvalContext *ec,
 		gbrun_form_widget_set_color (fi->widget, GBRUN_FORM_COLOR_BORDER, val->v.l);
 		return TRUE;
 
+	case VISIBLE:
+		if (val->v.bool)
+			gtk_widget_show (fi->widget);
+		else
+			gtk_widget_hide (fi->widget);
+		return TRUE;
+
 	default:
 		g_warning ("Bad property set %d", property);
 		return FALSE;
@@ -119,6 +128,9 @@ form_item_getarg (GBRunEvalContext *ec,
 	case TABINDEX:
 		return gb_value_new_int (fi->tabindex);
 
+	case VISIBLE:
+		return gb_value_new_boolean (GTK_WIDGET_VISIBLE (fi->widget));
+
 	default:
 		g_warning ("Bad property get %d", property);
 		break;
@@ -258,6 +270,7 @@ gbrun_form_item_class_init (GBRunObjectClass *klass)
 	gbrun_object_add_property (klass, "left",   gb_type_int, LEFT);
 
 	gbrun_object_add_property (klass, "tabindex", gb_type_int, TABINDEX);
+	gbrun_object_add_property (klass, "visible",  gb_type_boolean, VISIBLE);
 
 	gbrun_object_add_property (klass, "ForeColor",   gb_type_long, FORE_COLOR);
 	gbrun_object_add_property (klass, "BackColor",   gb_type_long, BACK_COLOR);
