@@ -244,7 +244,7 @@ form_setarg (GBRunEvalContext *ec,
 		return TRUE;
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("form: Unhandled property '%d'", property);
 		return FALSE;
 	}
 }
@@ -281,7 +281,7 @@ form_getarg (GBRunEvalContext *ec,
 		return gb_value_new_int (GBRUN_FORM_Y_TO_TWIPS (i));
 	}
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("form: Unhandled property '%d'", property);
 		break;
 	}
 
@@ -348,6 +348,10 @@ gbrun_form_pass_properties (GBRunEvalContext *ec,
 			    GBFormItem       *item)
 {
 	GSList *l;
+
+	g_return_if_fail (item != NULL);
+	g_return_if_fail (GBRUN_IS_OBJECT (obj));
+	g_return_if_fail (GBRUN_IS_EVAL_CONTEXT (ec));
 	
 	for (l = item->properties; l; l = l->next) {
 		GBFormProperty *prop = l->data;
@@ -451,6 +455,8 @@ gbrun_form_init (GBRunEvalContext  *ec,
 	g_return_if_fail (form != NULL);
 
 	item = pd->form;
+	g_return_if_fail (item != NULL);
+
 	gbrun_form_pass_properties (ec, GBRUN_OBJECT (form), item);
 
 	for (l = item->children; l; l = l->next) {
