@@ -1,4 +1,3 @@
-
 /*
  * gbrun-objects.c
  *
@@ -27,14 +26,15 @@ gbrun_objects_register (GBEvalContext *ec)
 	gbrun_checkbox_register();
 	gbrun_timer_register ();
 	gbrun_picturebox_register ();
-
-/*	gbrun_listbox_register ();
-	gbrun_frame_register();*/
+	gbrun_listbox_register ();
+	gbrun_frame_register();
 }
 
 void
 gbrun_objects_shutdown (void)
 {
+	gbrun_frame_shutdown ();
+	gbrun_listbox_shutdown ();
 	gbrun_checkbox_shutdown ();
 	gbrun_picturebox_shutdown ();
 	gbrun_timer_shutdown ();
@@ -43,7 +43,4 @@ gbrun_objects_shutdown (void)
 	gbrun_cmdbutton_shutdown ();
 	gbrun_form_item_shutdown ();
 	gbrun_form_shutdown ();
-
-/*	gbrun_listbox_shutdown ();
-	gbrun_frame_shutdown ();*/
 }
