@@ -12,6 +12,15 @@
 #define GBRUN_OBJECTS_H
 
 /* Internal */
+GtkType gbrun_cmdbutton_get_type (void);
+GtkType gbrun_label_get_type     (void);
+GtkType gbrun_listbox_get_type   (void);
+GtkType gbrun_textbox_get_type   (void);
+GtkType gbrun_timer_get_type     (void);
+GtkType gbrun_picturebox_get_type(void);
+GtkType gbrun_frame_get_type     (void);
+GtkType gbrun_checkbox_get_type  (void);
+
 void gbrun_cmdbutton_register (void);
 void gbrun_label_register     (void);
 void gbrun_listbox_register   (void);
@@ -19,7 +28,7 @@ void gbrun_textbox_register   (void);
 void gbrun_timer_register     (void);
 void gbrun_picturebox_register(void);
 void gbrun_frame_register     (void);
-void gbrun_check_register     (void);
+void gbrun_checkbox_register  (void);
 
 void gbrun_cmdbutton_shutdown (void);
 void gbrun_label_shutdown     (void);
@@ -27,7 +36,7 @@ void gbrun_listbox_shutdown   (void);
 void gbrun_textbox_shutdown   (void);
 void gbrun_timer_shutdown     (void);
 void gbrun_picturebox_shutdown(void);
-void gbrun_check_shutdown     (void);
+void gbrun_checkbox_shutdown  (void);
 void gbrun_frame_shutdown     (void);
 
 
