@@ -65,7 +65,7 @@ textbox_setarg (GBRunEvalContext *ec,
 	case ALIGNMENT: {
 		static gboolean warned = FALSE;
 		if (!warned) {
-			g_warning ("GtkEntry alignment unsupported");
+			g_warning ("textbox: GtkEntry alignment unsupported");
 			warned = TRUE;
 		}
 
@@ -73,7 +73,7 @@ textbox_setarg (GBRunEvalContext *ec,
 	}
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("textbox: Unhandled property '%d'", property);
 		return FALSE;
 	}
 }
@@ -105,7 +105,7 @@ textbox_getarg (GBRunEvalContext *ec,
 			gtk_entry_get_text (entry));
 
 	default:
-		g_warning ("Unhandled property '%d'", property);
+		g_warning ("textbox: Unhandled property '%d'", property);
 		return NULL;
 	}
 }
